# /home/jon/Namizje/Projekti/kroky-library/kroky/__init__.py

# This file indicates that the kroky directory is a Python package.
# You can initialize package-level variables or import submodules here.

# Example of importing a submodule
# from . import submodule_name

# Example of initializing a package-level variable
# package_variable = "This is a package-level variable"

from .main import Kroky